/*****************************************************************/
/* JS/CSS file 'ctl_silk.js' for SeeDeClip4 DMS                        */
/*    Copyright (c) 2016 Cutestudio Ltd., All Rights Reserved.   */
/*****************************************************************/


//** SILK TO HTML
var indent = 0;
var indentdx = 40;
var table_idx = 0;
var silk_local = ".";
var text_kill_lf = false;
var text_sizeinfo = "";

function silk_ending(cmd)
{
 var output;

 switch(cmd)
 {
  case 'ul': case 'ol':
   output = '</li></'+cmd+'>';
   text_kill_lf = true;
  break;
  case 'indent':
   text_kill_lf = true;
   indent -= indentdx;
   output = '</div>';
  break;
  case 'div': case 'blockquote':
   text_kill_lf = true;
   output = '</'+cmd+'>\n';
  break;
  case 'h1': case 'h2': case 'h3': case 'h4': case 'h5':
   text_kill_lf = true;
   text_kill_lf = true;
   output = '</'+cmd+'>\n';
  break;
  case 'td': case 'th':
   text_kill_lf = true;
   text_kill_lf = true;
   output = '</'+cmd+'></tr></tbody></table>';
   if (table_idx) table_idx --;
  break;
  case 'unknown': output = '[]'; break;
  case 'a':
   output = '</'+cmd+'>';
  break;
  default:
   output = '</'+cmd+'>';
  break;
 }
 return output;
}

function table_precmd(precmd)
{
 var extra = '';
 if (precmd)
 {
  var num = parseInt(precmd);
  if (num > 0)
  {
   extra += 'colspan="'+num+'"';
   precmd = precmd.substring(1);
  }

  switch(precmd)
  {
   case 'L': extra += 'style="text-align: left;"';   break;
   case 'R': extra += 'style="text-align: right;"';  break;
   case 'C': extra += 'style="text-align: center;"'; break;
   case 'T': extra += 'style="vertical-align: top;"';    break;
   case 'M': extra += 'style="vertical-align: middle;"'; break;
   case 'B': extra += 'style="vertical-align: bottom;"'; break;
   default:
    extra += precmd;
   break;
  }
 }

 return (extra) ? ' ' + extra : '';
}

//** Cute to HTML
//** If 'limit' is set, the conversion is terminated after the number of
function silk2html(cute, limit)
{
 var stack = new Array();
 var sp = 0, t_type, t_pos;
 var t_row = new Array();
 var output = '';
 var first_h = true;

 text_kill_lf = false;

 var inbrac = false;
 var cmd  = '';
 var text = '';
 if (!limit || (limit > cute.length))
  limit = cute.length;

 text_kill_lf = false;
 for (var c=0; c<limit; c++)
 {
  var ch = cute.charAt(c);

  switch (ch)
  {
   case '\r': break;
   case '\n':
    if (text_kill_lf)
     text_kill_lf = false;
    else
     text += '<br/>';
   break;
   case '\t': text += ' '; break;
   case '[':
    if ((c+1) < cute.length)
    {
     ch = cute.charAt(c+1);
     if (ch == '[')
     {
      text += '[';
      c++;
      break;
     }
    }
    inbrac = true;
    output += text;
    text = '';
   break;
   case ']':
    if (!inbrac)
    {
     text += ch;
     break;
    }
    inbrac = false;

    var precmd = null;
    var ocmd = cmd;
    if (cmd)
    {
     var idx = cmd.indexOf("|");
     if (idx != -1)
     {
      precmd = cmd.substring(0,idx);
      cmd = cmd.substr(idx+1);
     }
    }

    switch(cmd)
    {
     case '':
      if (sp > 0)
      {
       cmd = stack[--sp];
       output += silk_ending(cmd);
      }
     break;
     case 'b': case 'i': case 'u':
     case 'h1': case 'h2': case 'h3': case 'h4': case 'h5':
      stack[sp++] = cmd;
      if (first_h)
       { output += '<'+cmd+' style="padding-top:0px">'; first_h = false; }
      else
       output += '<'+cmd+'>';
     break;
     case 'L': stack[sp++] = 'div'; output += '<div align="left">'; break;
     case 'C': stack[sp++] = 'div'; output += '<div align="center">'; break;
     case 'R': stack[sp++] = 'div'; output += '<div align="right">'; break;
     case 'br':
      if (!text_kill_lf) output += '<br/>';
     break;
     case 'p':
     case 'hr': output += '<'+cmd+'/>'; text_kill_lf = true; break;
     case '*': case 'n':
      cmd = (cmd == '*') ? 'ul' : 'ol';
      stack[sp++] = cmd;
      output += '<'+cmd+'><li>';
     break;
     case '.':
      output += '</li>\n<li>';
     break;
     case 'aqua': case 'black': case 'blue': case 'fuchsia': case 'gray':
     case 'green': case 'lime': case 'maroon': case 'navy': case 'olive':
     case 'purple': case 'red': case 'silver': case 'teal': case 'white': case'yellow':
      stack[sp++] = 'span';
      var type = (precmd == 'b') ? 'background-color' : 'color';
      output += '<span style="'+type+':'+cmd+'">';
     break;
     case "serif": case "sans-serif": case "monospace": case "cursive": case "fantasy":
      stack[sp++] = 'span';
      output += '<span style="font-family:'+cmd+'">';
     break;
     case '1': case '2': case '3': case '4': case '5': case '6': case '7':
      stack[sp++] = 'font';
      output += '<font size='+cmd+'>';
     break;
     case 'I': stack[sp++] = "blockquote"; output += "<blockquote>"; break;
     case 'd': stack[sp++] = "del"; output += "<del>"; break;
     case 'TABLE': case 'table':
      var extra = table_precmd(precmd);
      t_row[++table_idx] = 1;
      t_type = (cmd == 'TABLE') ? "th" : "td";
      stack[sp++] = t_type;
      if (extra.indexOf('outline') != -1)
      {
       extra = extra.replace("outline", "");
       output += '<table><tbody><tr><'+t_type+extra+'>';
      }
      else
       output += '<table class="cute"><tbody><tr><'+t_type+extra+'>';
      t_pos = sp;
     break;
     case 'ROW': case 'row':
      var extra = table_precmd(precmd);
      t_row[table_idx]++;
      t_type = (cmd == 'ROW') ? "th" : "td";
      while (sp > t_pos)
       { cmd = stack[--sp]; output += silk_ending(cmd); }
      var t_cl = (t_row[table_idx] & 1) ? 'class="odd"' : '';
      output += '</'+stack[sp-1]+'></tr>\n<tr '+t_cl+'><'+t_type+extra+'>';
      stack[sp-1] = t_type;
     break;
     case 'COL': case 'col':
      var extra = table_precmd(precmd);
      t_type = (cmd == 'COL') ? "th" : "td";
      while (sp > t_pos)
       { cmd = stack[--sp]; output += silk_ending(cmd); }
      output += '</'+stack[sp-1]+'><'+t_type+extra+'>';
      stack[sp-1] = t_type;
     break;
     case '^': stack[sp++] = "sup"; output += "<sup>"; break;
     case 'v': stack[sp++] = "sub"; output += "<sub>"; break;
     case "copy": case "pound": case "cent": case "reg": case "deg": case "pi":
     case "micro": case "sum": case "alpha": case "beta": case "delta": case "euro":
      output += "&" + cmd + ";";
     break;
     case "U": output += "&micro;"; break;
     case "bullet": output += "&bull;"; break;
     case "x": output += "&middot;"; break;
     case ">>": output += "&raquo;"; break;
     case "->": output += "&rarr;"; break;
     case "<-": output += "&larr;"; break;
     case "<=": output += "&le;"; break;
     case ">=": output += "&ge;"; break;
     case "up": output += "&uarr;"; break;
     case "down": output += "&darr;"; break;
     case "<<": output += "&laquo;"; break;
     case "+-": output += "&plusmn;"; break;
     case "^2": output += "&sup2;"; break;
     case "^3": output += "&sup3;"; break;
     case "1/4": output += "&frac14;"; break;
     case "1/2": output += "&frac12;"; break;
     case "3/4": output += "&frac34;"; break;
     case "ohms": output += "&Omega;"; break;
     case "t": output += "&tau;"; break;
     case "tm": output += "&trade;"; break;
     case "root": output += "&radic;"; break;
     case "/": output += "&divide;"; break;
     case "oo": output += "&infin;"; break;
     case "yes": output += '<font size="+1"><b>&#x2713;</b></font></span>'; break;
     case "no":  output += '<span style="color:#bbb;">&#x2717;</span>';    break;
     case "html":
      var htm = cute.substring(c);
      var ie  = htm.indexOf('[]');
      if (ie <= 0) break;
      var str = htm.substring(1, ie);
      output += str;
      c += ie + 1;
     break;
     case 'code':
      var htm = cute.substring(c);
      var ie  = htm.indexOf('\n[]');
      if (ie <= 0) break;
      var str = htm.substring(1, ++ie);
      var pos = 0, ilf = true;

      output += '<table class="code"><tr><td><div class="code">';
      for (var d=0; d<str.length; d++)
      {
       var h = str.charAt(d);
       switch(h)
       {
        case '<':  output += '&lt;';   break;
        case '>':  output += '&gt;';   break;
        case '&':  output += '&amp;';  break;
        case '"':  output += '&quot;'; break;
        case '\'': output += '&#039;'; break;
        case '\t':
         do { output += '&nbsp;'; } while (++pos % 4);
         pos--;
        break;
        case '\r': break;
        case '\n':
         pos = -1;
         if (ilf)
          ilf = false;
         else
          output += '<br/>\n';
        break;
        default:  output += h; break;
       }
       pos++;
      }
      output += '</div></td></tr></table>';
      c += ie + 1;
     break;
     case 'codebox':
      output += '<table class="code"><tr><td><div class="code">';
      stack[sp++] = 'div></td></tr></table';
      text_kill_lf = true;
     break;
     case "ctl_open":  output += "&lt;?ctl"; break;
     case "ctl_close": output += "?&gt;"; break;
     default:
      var unknown = true;
      switch(cmd.charAt(0))
      {
       case '#':
        var rgb = cmd.substr(1);
        rgb = rgb.toLowerCase();
        if (((rgb.length == 3) || (rgb.length == 6))
         && (!rgb.match(/[^0-9a-f]/)))
        {
         stack[sp++] = 'span';
         type = (precmd == 'b') ? 'background-color' : 'color';
         output += '<span style="'+type+':#'+rgb+';">';
         unknown = false;
        }
       break;
       case 's':
        var num = cmd.substr(1);
        if ((num.length == 2) && (num >= 1) && (num <= 25))
        {
         output += '<img alt="Smiley '+num+'" src="'+text_static+'/'+cmd+'.gif"/>';
         unknown = false;
        }
       break;
       case '_': case ' ':
        var len = cmd.length;
        while (len--) output += '&nbsp;';
        unknown = false;
       break;
       case '-': case '+':
        var inc = cmd.charAt(1);
        if (inc < 1) inc = 1; else if (inc > 7) inc = 7;
        stack[sp++] = 'font';
        output += '<font size="'+cmd.charAt(0)+inc+'">';
        unknown = false;
       break;
       case '@':  case 'W':

        var addr = ocmd.substr(1);
        var proto = "";
        if (ocmd.charAt(0) == '@')
         proto = 'mailto:';
        else
        {
         if (ocmd.indexOf('www.') == 1) proto = 'http://';

        }
        output += '<a href="'+proto+addr+'">';
        stack[sp++] = 'a';
        unknown = false;
       break;
       case 'P':
        var pex = (precmd) ? 'width="'+precmd+'px"' : '';
        var img = cmd.substr(1);
        var src = (silk_local && (cmd.indexOf(":") == -1)) ? silk_local+'/'+img : img;

        output += '<img alt="'+img+'" '+pex+' src="'+src+'"/>';
        unknown = false;
       break;
      }

      if (unknown)
      {
       var idx = cmd.indexOf("pt");
       if (idx && (idx != -1))
       {
        stack[sp++] = 'span';
        output += '<span style="font-size:'+cmd+'">';
        unknown = false;
       }
      }
      if (unknown)
      {
       stack[sp++] = 'unknown';
       output += '['+cmd+']';
      }
     break;
    }
    cmd = '';
   break;
   default:
    if (inbrac)
     cmd += ch;
    else
    {
     switch (ch)
     {
      case '<':  text += '&lt;'; break;
      case '>':  text += '&gt;'; break;
      case '&':  text += '&amp;'; break;
      default:  text += ch; break;
     }
    }
   break;
  }
 }

 if (text) output += text;

 while (sp > 0)
 {
  cmd = stack[--sp];
  output += silk_ending(cmd);
 }

 silk_local = ".";

 return output;
}

